@@ -201,9 +201,9 @@ general_garch_fitting <- function(rt, model_type, orders = c(1, 1),
 
   if (is.null(start_pars) || is.null(LB) || is.null(UB)) {
     mean_rt <- list(NULL, mean(rt_core))[[incl_mean + 1]]
-    min_rt <- list(NULL, min(rt_core))[[incl_mean + 1]]
-    max_rt <- list(NULL, max(rt_core))[[incl_mean + 1]]
-    skew_start <- list(NULL, 1)[[skew_par + 1]]
+    min_rt <- list(NULL, suppressWarnings(0.2 * min(rt_core - mean_rt) + mean_rt))[[incl_mean + 1]]
+    max_rt <- list(NULL, suppressWarnings(0.2 * max(rt_core - mean_rt) + mean_rt))[[incl_mean + 1]]
+    skew_start <- list(NULL, 0.98)[[skew_par + 1]]
     skew_low <- list(NULL, 1e-15)[[skew_par + 1]]
     skew_up <- list(NULL, Inf)[[skew_par + 1]]
 
